@@ -86,7 +86,7 @@
 #define KNEWSTUFF_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNEWSTUFF_NO_DEPRECATED
-#  define KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
+#  define KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56100
 #endif
 #ifdef KNEWSTUFF_NO_DEPRECATED_WARNINGS
 #  define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0x55400
+#    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0x56100
 #  endif
 #endif
 
@@ -151,6 +151,24 @@
 #else
 #  define KNEWSTUFF_DEPRECATED_VERSION_5_82(text)
 #endif
+
+#if KNEWSTUFF_DEPRECATED_WARNINGS_SINCE >= 0x55500
+#  define KNEWSTUFF_DEPRECATED_VERSION_5_85(text) KNEWSTUFF_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KNEWSTUFF_DEPRECATED_VERSION_5_85(text)
+#endif
+
+#if KNEWSTUFF_DEPRECATED_WARNINGS_SINCE >= 0x55b00
+#  define KNEWSTUFF_DEPRECATED_VERSION_5_91(text) KNEWSTUFF_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KNEWSTUFF_DEPRECATED_VERSION_5_91(text)
+#endif
+
+#if KNEWSTUFF_DEPRECATED_WARNINGS_SINCE >= 0x55e00
+#  define KNEWSTUFF_DEPRECATED_VERSION_5_94(text) KNEWSTUFF_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KNEWSTUFF_DEPRECATED_VERSION_5_94(text)
+#endif
 #define KNEWSTUFF_DEPRECATED_VERSION_5(minor, text)      KNEWSTUFF_DEPRECATED_VERSION_5_##minor(text)
 #define KNEWSTUFF_DEPRECATED_VERSION(major, minor, text) KNEWSTUFF_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KNEWSTUFF_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KNEWSTUFF_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -216,7 +234,7 @@
 #define KNEWSTUFF_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNEWSTUFF_NO_DEPRECATED
-#  define KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
+#  define KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56100
 #endif
 #ifdef KNEWSTUFF_NO_DEPRECATED_WARNINGS
 #  define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0
@@ -226,7 +244,7 @@
 #  ifdef KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0x55400
+#    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0x56100
 #  endif
 #endif
 
@@ -281,6 +299,24 @@
 #else
 #  define KNEWSTUFF_DEPRECATED_VERSION_5_82(text)
 #endif
+
+#if KNEWSTUFF_DEPRECATED_WARNINGS_SINCE >= 0x55500
+#  define KNEWSTUFF_DEPRECATED_VERSION_5_85(text) KNEWSTUFF_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KNEWSTUFF_DEPRECATED_VERSION_5_85(text)
+#endif
+
+#if KNEWSTUFF_DEPRECATED_WARNINGS_SINCE >= 0x55b00
+#  define KNEWSTUFF_DEPRECATED_VERSION_5_91(text) KNEWSTUFF_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KNEWSTUFF_DEPRECATED_VERSION_5_91(text)
+#endif
+
+#if KNEWSTUFF_DEPRECATED_WARNINGS_SINCE >= 0x55e00
+#  define KNEWSTUFF_DEPRECATED_VERSION_5_94(text) KNEWSTUFF_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KNEWSTUFF_DEPRECATED_VERSION_5_94(text)
+#endif
 #define KNEWSTUFF_DEPRECATED_VERSION_5(minor, text)      KNEWSTUFF_DEPRECATED_VERSION_5_##minor(text)
 #define KNEWSTUFF_DEPRECATED_VERSION(major, minor, text) KNEWSTUFF_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KNEWSTUFF_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KNEWSTUFF_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
